@@ -3,7 +3,7 @@ package Bencher::Scenario::Z::Overhead;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-08'; # DATE
 our $DIST = 'Bencher-Scenarios-Z'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,23 +13,25 @@ our $scenario = {
     summary => 'Measure startup overhead of Z',
     code_startup => 1,
     participants => [
-        {code_template=>'use Z;'},
-        {code_template=>'use Z -modern;'},
-        {code_template=>'use Z -compat;'},
-        {code_template=>'use Z -detect;'},
+        # the extra_modules is there so the Pod::Weaver plugin can show the used
+        # module's versions
+        {code_template=>'use Z;', extra_modules=>['Z']},
+        {code_template=>'use Z -modern;', extra_modules=>['Z']},
+        {code_template=>'use Z -compat;', extra_modules=>['Z']},
+        {code_template=>'use Z -detect;', extra_modules=>['Z']},
 
-        {code_template=>'use Type::Tiny;'},
-        {code_template=>'use Types::Standard;'},
+        {code_template=>'use Type::Tiny;', extra_modules=>['Type::Tiny']},
+        {code_template=>'use Types::Standard;', extra_modules=>['Types::Standard']},
 
-        {code_template=>'use Zydeco;'},
+        {code_template=>'use Zydeco;', extra_modules=>['Zydeco']},
 
-        {code_template=>'use Zydeco::Lite;'},
+        {code_template=>'use Zydeco::Lite;', extra_modules=>['Zydeco::Lite']},
 
-        {code_template=>'use MooX::Press;'},
+        {code_template=>'use MooX::Press;', extra_modules=>['MooX::Press']},
 
-        {code_template=>'use Moo;'},
+        {code_template=>'use Moo;', extra_modules=>['Moo']},
 
-        {code_template=>'use Moose;'},
+        {code_template=>'use Moose;', extra_modules=>['Moose']},
     ],
 };
 
@@ -48,7 +50,7 @@ Bencher::Scenario::Z::Overhead - Measure startup overhead of Z
 
 =head1 VERSION
 
-This document describes version 0.004 of Bencher::Scenario::Z::Overhead (from Perl distribution Bencher-Scenarios-Z), released on 2020-10-08.
+This document describes version 0.005 of Bencher::Scenario::Z::Overhead (from Perl distribution Bencher-Scenarios-Z), released on 2020-10-08.
 
 =head1 SYNOPSIS
 
@@ -166,18 +168,18 @@ Benchmark with default options (C<< bencher -m Z::Overhead >>):
  +----------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
  | participant          | time (ms) | code_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +----------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
- | use Zydeco;          |     164   |              157.6 |                 0.00% |              2468.18% |   0.00014 |      20 |
- | use Moose;           |     140   |              133.6 |                14.87% |              2135.66% |   0.00098 |      21 |
- | use Z;               |     120   |              113.6 |                35.18% |              1799.79% |   0.00016 |      20 |
- | use Z -detect;       |     120   |              113.6 |                35.25% |              1798.89% |   0.00021 |      20 |
- | use Z -modern;       |     120   |              113.6 |                35.82% |              1790.85% |   0.00013 |      20 |
- | use Z -compat;       |     120   |              113.6 |                36.83% |              1776.93% |   0.00015 |      20 |
- | use MooX::Press;     |      91   |               84.6 |                80.91% |              1319.55% |   0.00011 |      20 |
- | use Zydeco::Lite;    |      75   |               68.6 |               118.06% |              1077.75% |   0.00013 |      20 |
- | use Types::Standard; |      47   |               40.6 |               252.29% |               628.99% |   0.00025 |      23 |
- | use Type::Tiny;      |      19   |               12.6 |               785.24% |               190.11% | 7.7e-05   |      20 |
- | use Moo;             |      18   |               11.6 |               804.45% |               183.95% | 4.4e-05   |      20 |
- | perl -e1 (baseline)  |       6.4 |                0   |              2468.18% |                 0.00% | 9.6e-06   |      20 |
+ | use Zydeco;          |     164   |              157.3 |                 0.00% |              2338.27% |   0.00013 |      20 |
+ | use Moose;           |     140   |              133.3 |                19.30% |              1943.85% |   0.00022 |      20 |
+ | use Z;               |     120   |              113.3 |                35.02% |              1705.90% |   0.00021 |      20 |
+ | use Z -modern;       |     120   |              113.3 |                35.83% |              1695.06% |   0.00013 |      20 |
+ | use Z -detect;       |     120   |              113.3 |                36.25% |              1689.55% |   0.00017 |      20 |
+ | use Z -compat;       |     120   |              113.3 |                37.35% |              1675.24% | 8.9e-05   |      20 |
+ | use MooX::Press;     |      91   |               84.3 |                80.00% |              1254.63% |   0.00013 |      20 |
+ | use Zydeco::Lite;    |      75   |               68.3 |               117.93% |              1018.85% | 8.1e-05   |      20 |
+ | use Types::Standard; |      44   |               37.3 |               271.61% |               556.13% | 5.6e-05   |      20 |
+ | use Type::Tiny;      |      18.3 |               11.6 |               798.93% |               171.24% | 1.3e-05   |      20 |
+ | use Moo;             |      18   |               11.3 |               809.10% |               168.21% | 2.5e-05   |      20 |
+ | perl -e1 (baseline)  |       6.7 |                0   |              2338.27% |                 0.00% | 1.7e-05   |      20 |
  +----------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
 
 
